# /etc/profile.d/sum.sh

if [[ "${BASH_SOURCE[0]}" == "${0}" ]]; then
  echo "This script should be sourced, not executed."
  exit 1
fi

# Function to generate SHA-256 hashes for .sh files in src or dist directories
release_hash() {
  local base_dir="$1"

  # Check if the base directory exists
  if [ ! -d "$base_dir" ]; then
    echo "Base directory $base_dir does not exist."
    return 1
  fi

  # Use shasum by default, and fallback to sha256sum if available
  local hash_cmd="shasum -a 256"
  if command -v sha256sum >/dev/null 2>&1; then
    hash_cmd="sha256sum"
  fi

  # Function to process a directory
  process_directory() {
    local dir="$1"
    for file in "$dir"/*.sh; do
      # Skip if no .sh files are found
      [ -e "$file" ] || continue

      # Calculate the SHA-256 hash and save it to a .sha256 file
      $hash_cmd "$file" | awk '{ print $1 }' > "$file.sha256"
    done
  }

  # Process src and dist directories if they exist
  for sub_dir in src dist; do
    local full_dir="$base_dir/$sub_dir"
    if [ -d "$full_dir" ]; then
      process_directory "$full_dir"
    fi
  done

  echo "SHA-256 hashes have been saved in .sha256 files."
}

